[commit] r1351 - trunk/SDK/DecoratorWizard

GMESRC Repository Notifications gme-commit at list.isis.vanderbilt.edu
Mon Jun 13 16:29:21 CDT 2011


Author: ksmyth
Date: Mon Jun 13 16:29:20 2011
New Revision: 1351

Log:
Upgrade to VS10

Modified:
   trunk/SDK/DecoratorWizard/setup100.js

Modified: trunk/SDK/DecoratorWizard/setup100.js
==============================================================================
--- trunk/SDK/DecoratorWizard/setup100.js	Mon Jun 13 16:23:01 2011	(r1350)
+++ trunk/SDK/DecoratorWizard/setup100.js	Mon Jun 13 16:29:20 2011	(r1351)
@@ -11,7 +11,7 @@
 // the terms of this license. You must not remove this notice, or
 // any other, from this software.
 
 // Setup program for the Decorator Wizard for VC++ 9.0 (Visual Studio 2008)
 
 
 main();
@@ -74,19 +74,19 @@
 
 	try
 	{
-		var strVC9Key = "HKLM\\Software\\Microsoft\\VisualStudio\\9.0\\Setup\\VC\\ProductDir";
-		strValue = WSShell.RegRead(strVC9Key);
+		var strVC10Key = "HKLM\\Software\\Microsoft\\VisualStudio\\10.0\\Setup\\VC\\ProductDir";
+		strValue = WSShell.RegRead(strVC10Key);
 	}
 	catch(e)
 	{
 		try
 		{
-			var strVC9Key_x64 = "HKLM\\Software\\Wow6432Node\\Microsoft\\VisualStudio\\9.0\\Setup\\VC\\ProductDir";
-			strValue = WSShell.RegRead(strVC9Key_x64);
+			var strVC10Key_x64 = "HKLM\\Software\\Wow6432Node\\Microsoft\\VisualStudio\\10.0\\Setup\\VC\\ProductDir";
+			strValue = WSShell.RegRead(strVC10Key_x64);
 		}
 		catch(e)
 		{
-			WScript.Echo("ERROR: Cannot find where Visual Studio 2008 is installed.");
+			WScript.Echo("ERROR: Cannot find where Visual Studio 2010 is installed.");
 			return;
 		}
 	}
@@ -146,9 +146,9 @@
 		{
 			var strLine = fileSrc.ReadLine();
 			if(strLine.indexOf("Wizard=VsWizard.VsWizardEngine") != -1)
-				strLine = "Wizard=VsWizard.VsWizardEngine.9.0";
+				strLine = "Wizard=VsWizard.VsWizardEngine.10.0";
 			else if(strLine.indexOf("WIZARD_VERSION") != -1)
-				strLine = "Param=\"WIZARD_VERSION = 9.0\"";
+				strLine = "Param=\"WIZARD_VERSION = 10.0\"";
 			else if(strLine.indexOf("ABSOLUTE_PATH") != -1)
 				strLine = "Param=\"ABSOLUTE_PATH = " + strSourceFolder + "\"";
 			fileDest.WriteLine(strLine);
@@ -11,7 +11,7 @@
 // any other, from this software.
 
-// Setup program for the Decorator Wizard for VC++ 9.0 (Visual Studio 2008)
+// Setup program for the Decorator Wizard for VC++ 10.0 (Visual Studio 2010)
 
 


More information about the gme-commit mailing list